# Exposure Fusion

Python implementation of exposure fusion of multiple images, using the alghorithm described in:

Mertens, Tom, Jan Kautz, and Frank Van Reeth. "Exposure fusion." Computer Graphics and Applications, 2007. PG'07. 15th Pacific Conference on. IEEE, 2007.

## Requirements

- Python 2.7 or Python 3
- OpenCV python module (cv2)

## Installation
```
pip install exposure_fusion
```

## Usage
See ```example.py```
